/**
 * Gaming Tools
 * Copyright (C) 2003  Michael Birken
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * @author Michael Birken (o__1@hotmail.com)
 * @version 2.1
 */
package gamingtools;

import com.sun.j3d.utils.timer.J3DTimer;

/**
 * Used for timing the execution of a code segment. It applies the
 * Java 3D class <CODE>com.sun.j3d.utils.timer.J3DTimer</CODE>.
 * @see gamingtools.StopWatchSource
 */
class J3DStopWatch implements StopWatch {

  /** Stores the start time. */
  private long counter;

  /**
   * Starts timing.
   */
  public void start() {
    counter = J3DTimer.getValue();
  }

  /**
   * Stops timing and returns the elapsed time in nanoseconds
   * (10<SUP>-9</SUP> seconds).
   * @return The duration since <CODE>start()</CODE> was called.
   */
  public long stop() {
    return J3DTimer.getValue() - counter;
  }

  /**
   * The error expected in the measured elapsed time; meaning, the actual
   * elapsed time is somewhere in the range of the measured elapsed time
   * plus-or-minus this value.
   * @return Error expected in measured elapsed time in nanoseconds
   * (10<SUP>-9</SUP> seconds).
   */
  public long getResolution() {
    return J3DTimer.getResolution();
  }
}