/**
 * Gaming Tools
 * Copyright (C) 2003  Michael Birken
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * @author Michael Birken (o__1@hotmail.com)
 * @version 2.1
 */
package gamingtools;

import javax.media.SystemTimeBase;

/**
 * Used for timing the execution of a code segment. It applies the
 * Java Media Framework class <CODE>javax.media.SystemTimeBase</CODE>.
 * @see gamingtools.StopWatchSource
 */
class JMFStopWatch implements StopWatch {

  /** Stores the start time. */
  private long counter;
  /** Used to obtain the current time. */
  private SystemTimeBase systemTimeBase = new SystemTimeBase();

  /**
   * Starts timing.
   */
  public void start() {
    counter = systemTimeBase.getNanoseconds();
  }

  /**
   * Stops timing and returns the elapsed time in nanoseconds
   * (10<SUP>-9</SUP> seconds).
   * @return The duration since <CODE>start()</CODE> was called.
   */
  public long stop() {
    return systemTimeBase.getNanoseconds() - counter;
  }

  /**
   * The error expected in the measured elapsed time; meaning, the actual
   * elapsed time is somewhere in the range of the measured elapsed time
   * plus-or-minus this value.
   * @return Error expected in measured elapsed time in nanoseconds
   * (10<SUP>-9</SUP> seconds).
   */
  public long getResolution() {
    long total, count1, count2;

    count1 = systemTimeBase.getNanoseconds();
    count2 = systemTimeBase.getNanoseconds();
    while(count1 == count2)
      count2 = systemTimeBase.getNanoseconds();
    total = count2 - count1;

    count1 = systemTimeBase.getNanoseconds();
    count2 = systemTimeBase.getNanoseconds();
    while(count1 == count2)
      count2 = systemTimeBase.getNanoseconds();
    total += count2 - count1;

    count1 = systemTimeBase.getNanoseconds();
    count2 = systemTimeBase.getNanoseconds();
    while(count1 == count2)
      count2 = systemTimeBase.getNanoseconds();
    total += count2 - count1;

    count1 = systemTimeBase.getNanoseconds();
    count2 = systemTimeBase.getNanoseconds();
    while(count1 == count2)
      count2 = systemTimeBase.getNanoseconds();
    total += count2 - count1;

    return total / 4;
  }
}