/**
 * Meat Fighter
 * Copyright (C) 2003  Michael Birken
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Meat Fighter and JaminWare are trademarks of Michael Birken.
 * All Rights Reserved.
 * http://www.meatfighter.com
 * o__1@hotmail.com
 */
package meatfighter;

import gamingtools.*;

public class AudioProxy implements Audio {

  public static final int MAX_PLAYING = 3;

  private static volatile int playingCount = 0;

  private Audio audio;
  private AudioListener audioListener;

  public AudioProxy(Audio audio) {
    this.audio = audio;
    this.audio.setAudioListener(new AudioListener() {
      public void audioStopped() {
        AudioProxy.this.audioStopped();
      }
    });
  }

  private void audioStopped() {
    playingCount = Math.max(playingCount - 1, 0);
    AudioListener listener = audioListener;
    if (listener != null)
      listener.audioStopped();
  }

  public void setAudioListener(AudioListener audioListener) {
    this.audioListener = audioListener;
  }

  public void clearAudioListener() {
    this.audioListener = null;
  }

  public void dispose() {
    audio.dispose();
  }

  public void play() {
    if (playingCount < MAX_PLAYING) {
      playingCount = Math.min(playingCount + 1, MAX_PLAYING);
      audio.play();
    }
  }

  public void loop() {
    if (playingCount < MAX_PLAYING) {
      playingCount = Math.min(playingCount + 1, MAX_PLAYING);
      audio.loop();
    }
  }

  public void stop() {
    playingCount = Math.max(playingCount - 1, 0);
    audio.stop();
  }
}