/**
 * Meat Fighter
 * Copyright (C) 2003  Michael Birken
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Meat Fighter and JaminWare are trademarks of Michael Birken.
 * All Rights Reserved.
 * http://www.meatfighter.com
 * o__1@hotmail.com
 */
package meatfighter;

import gamingtools.*;
import java.awt.*;
import javax.swing.*;
import java.awt.event.*;

public class BonusStage extends FrameBuilder {

  Image vsBackground, bsBackground, toasty, ready, vsbs;
  IFighter f1;
  IFighter f2;
  int tnum = Chaotic.nextInt(500, 999);
  int delay = 35, dx, dy, vx, vy, e = 6, bx, bxOld;
  boolean salFirst, fighting = true, animating = false;
  int soundMode = 0;
  InputSource inputSource;
  Audio musicBegin, musicFighting;

  public BonusStage(IFighter f) {
    f1 = f;
  }

  public void vsScreenDone() {
    Jukebox.loopMusic(musicFighting);
    animating = true;
  }

  public void beefDestroyed() {
    fighting = false;
    f1.setWinner();
    Jukebox.GIBBER3.play();
  }

  public void stageFinished() {
    Jukebox.stopMusic();
    MeatFighter.getInstance().humanOpponentWonStage();
  }

  public void init() {
    f2 = new Beef();
    f1.setOpponent(f2);
    f2.setOpponent(f1);
    f1.setFighter(true);
    f2.setFighter(false);
    f1.setAutomatic(false);
    f2.setAutomatic(true);
    f1.resetVitality();
    f2.resetVitality();

    f1.init();
    f2.init();

    Jukebox.SPLAT.setAudioListener(new AudioListener() {
      public void audioStopped() {
        beefDestroyed();
      }
    });

    Jukebox.GIBBER3.setAudioListener(new AudioListener() {
      public void audioStopped() {
        stageFinished();
      }
    });

    vsBackground = Gallery.BACKGROUND_VS;
    vsbs = Gallery.TEXT_BONUS_STAGE;
    toasty = Gallery.TOASTY;
    ready = Gallery.TEXT_READY;
    dx = (639-ready.getWidth(null)) >> 1;
    dy = (479-ready.getHeight(null)) >> 1;
    vx = (639-vsbs.getWidth(null)) >> 1;
    vy = (479-vsbs.getHeight(null)) >> 1;

    inputSource = InputFactory.getInputSource();
    inputSource.clearInputListener();

    bsBackground = Gallery.BACKGROUND_BONUS_STAGE;
    musicFighting = Jukebox.MUSIC_BONUS_STAGE;
    musicBegin = Jukebox.MUSIC_BONUS_STAGE_BEGIN;
    musicBegin.setAudioListener(new AudioListener() {
      public void audioStopped() {
        vsScreenDone();
      }
    });
    Jukebox.playMusic(musicBegin);
  }

  public void updateState() {
    if (animating == false)
      return;

    int x = f1.getX(), bx = -(x >> 2), ox = f2.getX();
    int orp = ox + bx;
    int diff = Math.abs(orp - x);

    if (delay == 0 && fighting) {
      if (inputSource.isBlock())
        f1.block();
      else {
        f1.unblock();
        if (inputSource.isPunch())
          f1.punch();
        if (inputSource.isKick())
          f1.kick();
        if (inputSource.isRight())
          f1.moveRight();
        else if (inputSource.isLeft())
          f1.moveLeft();
        if (inputSource.isUp()) {
          f1.jump();
        }
      }
    } else if (delay-- == 1)
      Jukebox.FIGHT.play();
    f1.update(orp, diff);
    f1.update();
    f2.update(x, orp, diff);
    f2.update();

    tnum--;
    if (tnum == 15) {
      Jukebox.TOASTY.play();
    } else if (tnum == 0)
      tnum = Chaotic.nextInt(500, 999);

    if (delay > 0 && fighting && --e == 0)
      e = 6;
  }

  public boolean isBackgroundSame() {
    if (animating == false)
      return true;
    return (bx == bxOld);
  }

  public void renderBackground(Graphics g) {
    if (animating == false) {
      g.drawImage(vsBackground, 0, 0, null);
      g.drawImage(vsbs, vx, vy, null);
      return;
    }

    g.drawImage(bsBackground, -(f1.getX() >> 2) - 15, 0, null);
  }

  public void renderBackground(
      Graphics g, int x, int y, int width, int height) {
    renderBackground(g);
  }

  public void renderForeground(Graphics g) {
    if (animating == false)
      return;

    int x = f1.getX(), ox = f2.getX();
    bxOld = bx;
    bx = -(x >> 2);
    int orp = ox + bx;
    int diff = Math.abs(orp - x);

    if (x > 290) {
      drawSprite(g, f1.getImage(), x, f1.getY());
      drawSprite(g, f2.getImage(), orp, f2.getY());
    } else {
      drawSprite(g, f2.getImage(), orp, f2.getY());
      drawSprite(g, f1.getImage(), x, f1.getY());
    }

    switch(tnum) {
      case 0:
        drawSprite(g, toasty, 608, 448);
        break;
      case 15:
        drawSprite(g, toasty, 608, 448);
        break;
      default:
        if (tnum < 15)
          drawSprite(g, toasty, 576, 416);
        break;
    }

    if (delay > 0 && fighting && e >= 3)
      drawSprite(g, ready, dx, dy);
  }
}