/**
 * Meat Fighter
 * Copyright (C) 2003  Michael Birken
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Meat Fighter and JaminWare are trademarks of Michael Birken.
 * All Rights Reserved.
 * http://www.meatfighter.com
 * o__1@hotmail.com
 */
package meatfighter;

import gamingtools.*;
import java.awt.*;
import javax.swing.*;
import java.awt.event.*;

public class DemoStage extends FrameBuilder implements AudioListener {

  final static Color red = new Color(0xaaff0000,true);
  final static Color yellow = new Color(0xaaffff00,true);
  final static Color white = new Color(0xaaffffff,true);

  final int STAGENUM = Chaotic.nextInt(0, 5);

  Image background, smoke1, smoke2, smoke, insertCoin, toasty;
  IFighter f1;
  IFighter f2;
  int iSmoke = 30, e = 6, oy, tnum = Chaotic.nextInt(500, 999);
  int smokeX, smokeY, smokeDelay;
  boolean f1First;
  Introduction intro;
  int bx, x, orp, W, X, Y, Q, lastBx;

  Audio music;

  IFighter getRandomFighter() {
    int r;
    do {
      r = Chaotic.nextInt(1, 6);
    } while(r == 2);

    return StageDescription.getFighter(r);
  }

  public void renderBackground(Graphics g) {
    g.drawImage(background, bx - 15, 0, null);
  }

  public void renderBackground(
      Graphics g, int x, int y, int width, int height) {
    renderBackground(g);
  }

  public void renderForeground(Graphics g) {

    drawSprite(g, smoke, bx + smokeX, smokeY);

    if (f1First) {
      drawSprite(g, f1.getImage(), x, f1.getY());
      drawSprite(g, f2.getImage(), orp, f2.getY());
    } else {
      drawSprite(g, f2.getImage(), orp, f2.getY());
      drawSprite(g, f1.getImage(), x, f1.getY());
    }

    if (e >= 3)
      drawSprite(g, insertCoin, oy, 420);

    if (tnum == 16 || tnum == 15) {
      drawSprite(g, toasty, 608, 448);
    } else if (tnum == 2 || tnum == 1) {
      drawSprite(g, toasty, 608, 448);
    } else if (tnum < 15)
      drawSprite(g, toasty, 576, 416);

    g.setColor(red);
    g.fillRect(10, 10, W, 15);
    g.fillRect(329+Y, 10, Q, 15);
    g.setColor(yellow);
    g.fillRect(W+10, 10, X, 15);
    g.fillRect(329, 10, Y, 15);
    g.setColor(white);
    g.drawRect(10, 10, 300, 15);
    markDirtyRegion(10, 10, 301, 16);
    g.drawRect(329, 10, 300, 15);
    markDirtyRegion(329, 10, 301, 16);
  }

  public boolean isBackgroundSame() {
    if (bx == lastBx)
      return true;
    lastBx = bx;
    return false;
  }

  public void audioStopped() {
    music.stop();
    GraphicsSource.setRenderListener(
        Introduction.getInstance(Introduction.STATE_NAMEUP));
  }

  public void updateState() {

    x = f1.getX();
    bx = -(x >> 2);
    int ox = f2.getX();
    orp = ox + bx;
    int diff = Math.abs(orp - x);

    f1.update(orp, x, diff);
    f1.update();

    f2.update(x, orp, diff);
    f2.update();

    if (f1.isPunched())
      f1First = true;
    else if (f2.isPunched())
      f1First = false;

    if (e-- == 0)
      e = 6;

    tnum--;
    if (tnum == 15) {
      Jukebox.TOASTY.play();
    } else if (tnum == 0) {
      tnum = Chaotic.nextInt(500, 999);
    }

    X = f1.getVitality();
    W = 300-X;
    Y = f2.getVitality();
    Q = 300-Y;

    if (iSmoke == 0) {
      iSmoke = smokeDelay;
      smoke = (smoke == smoke1) ? smoke2 : smoke1;
    } else
      iSmoke--;
  }

  public void init() {

    f1 = StageDescription.getFighter(STAGENUM+1);
    f2 = getRandomFighter();

    f1.init();
    f2.init();

    Jukebox.GIBBER.setAudioListener(this);
    Jukebox.GIBBER3.setAudioListener(this);

    music = Jukebox.MUSIC_STAGE[STAGENUM];
    Jukebox.loopMusic(music);
    background = Gallery.BACKGROUND_STAGE[STAGENUM];
    smoke1 = Gallery.ORNAMENT[STAGENUM][0];
    smoke2 = Gallery.ORNAMENT[STAGENUM][1];
    toasty = Gallery.TOASTY;
    insertCoin = Gallery.TEXT_PRESS_ENTER;
    smoke = smoke1;
    f1.setOpponent(f2);
    f2.setOpponent(f1);
    f1.setFighter(true);
    f2.setFighter(false);
    oy = (640 - insertCoin.getWidth(null)) >> 1;

    smokeX = MeatFighter.STAGEDESCRIPTION[STAGENUM].X;
    smokeY = MeatFighter.STAGEDESCRIPTION[STAGENUM].Y;
    iSmoke = smokeDelay = MeatFighter.STAGEDESCRIPTION[STAGENUM].TIME;
  }
}