/**
 * Meat Fighter
 * Copyright (C) 2003  Michael Birken
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Meat Fighter and JaminWare are trademarks of Michael Birken.
 * All Rights Reserved.
 * http://www.meatfighter.com
 * o__1@hotmail.com
 */
package meatfighter;

import gamingtools.*;
import java.awt.*;
import javax.swing.*;
import java.awt.event.*;

public class GenericStage extends FrameBuilder {

  final static Color red = new Color(0xaaff0000,true);
  final static Color yellow = new Color(0xaaffff00,true);
  final static Color white = new Color(0xaaffffff,true);

  Image background, smoke1, smoke2, smoke, toasty, ready;
  IFighter f1;
  IFighter f2;
  int iSmoke = 30, tnum = Chaotic.nextInt(500, 999);
  int delay, dx, dy, e = 6, bx, bxOld;
  int smokeX, smokeY, smokeDelay, stageNum;
  boolean salFirst, fighting = true, animating = true;
  InputSource inputSource;
  Audio musicStage;

  public GenericStage(IFighter f, int stageNum) {
    f1 = f;
    this.stageNum = stageNum;
  }

  public void init() {
    f2 = StageDescription.getFighter(stageNum+1);
    f1.setOpponent(f2);
    f2.setOpponent(f1);
    f1.setFighter(true);
    f2.setFighter(false);
    f1.setAutomatic(false);
    f2.setAutomatic(true);
    f1.resetVitality();
    f2.resetVitality();

    f1.init();
    f2.init();

    musicStage = Jukebox.MUSIC_STAGE[stageNum];
    Jukebox.loopMusic(musicStage);

    background = Gallery.BACKGROUND_STAGE[stageNum];
    smoke1 = Gallery.ORNAMENT[stageNum][0];
    smoke2 = Gallery.ORNAMENT[stageNum][1];
    toasty = Gallery.TOASTY;
    smoke = smoke1;
    ready = Gallery.TEXT_READY;
    dx = (639-ready.getWidth(null)) >> 1;
    dy = (479-ready.getHeight(null)) >> 1;

    smokeX = MeatFighter.STAGEDESCRIPTION[stageNum].X;
    smokeY = MeatFighter.STAGEDESCRIPTION[stageNum].Y;
    iSmoke = smokeDelay = MeatFighter.STAGEDESCRIPTION[stageNum].TIME;

    Jukebox.OUCH.setAudioListener(new AudioListener() {
      public void audioStopped() {
        fighterDied();
      }
    });
    AudioListener gibberListener = new AudioListener() {
      public void audioStopped() {
        fighterLost();
      }
    };
    Jukebox.GIBBER.setAudioListener(gibberListener);
    Jukebox.GIBBER3.setAudioListener(gibberListener);

    inputSource = InputFactory.getInputSource();
    inputSource.clearInputListener();
  }

  public void fighterLost() {
    fighting = false;
  }

  public void fighterDied() {
    fighting = false;
    animating = false;
    Jukebox.stopMusic();
    if (f1.isDead()) {
      MeatFighter.getInstance().humanOpponentLostStage();
    } else if (f2.isDead()) {
      MeatFighter.getInstance().humanOpponentWonStage();
    }
  }

  public void updateState() {
    if (animating == false)
      return;

    int x = f1.getX(), ox = f2.getX();
    bxOld = bx;
    bx = -(x >> 2);
    int orp = ox + bx;
    int diff = Math.abs(orp - x);
    if (delay == 0 && fighting) {
      if (inputSource.isBlock())
        f1.block();
      else {
        f1.unblock();
        if (inputSource.isPunch()) {
          f1.punch();
        }
        if (inputSource.isKick()) {
          f1.kick();
        }
        if (inputSource.isRight())
          f1.moveRight();
        else if (inputSource.isLeft())
          f1.moveLeft();
        if (inputSource.isUp()) {
          f1.jump();
        }
      }
      f1.update(orp, diff);
      f1.update();
      f2.update(x, orp, diff);
      f2.update();
    } else if (delay-- == 1)
      Jukebox.FIGHT.play();

    if (f1.isPunched())
      salFirst = true;
    else if (f2.isPunched())
      salFirst = false;

    tnum--;
    if (tnum == 15) {
      Jukebox.TOASTY.play();
    } else if (tnum == 0) {
      tnum = Chaotic.nextInt(500, 999);
    }

    if (delay > 0 && fighting && --e == 0) {
      e = 6;
    }

    if (iSmoke == 0) {
      iSmoke = smokeDelay;
      smoke = (smoke == smoke1) ? smoke2 : smoke1;
    } else
      iSmoke--;

    if (fighting == false) {
      fighting = true;
      f1.resetVitality();
      f1.update();
      f2.resetVitality();
      f2.update();
      delay = 35;
    }
  }

  public boolean isBackgroundSame() {
    return bx == bxOld;
  }

  public void renderBackground(Graphics g) {
    if (animating == false)
      return;
    g.drawImage(background, bx - 15, 0, null);
  }

  public void renderBackground(
      Graphics g, int x, int y, int width, int height) {
    renderBackground(g);
  }

  public void renderForeground(Graphics g) {
    if (animating == false)
      return;

    int x = f1.getX(), ox = f2.getX();
    int orp = ox + bx;
    int diff = Math.abs(orp - x);

    drawSprite(g, smoke, bx + smokeX, smokeY);

    if (salFirst) {
      drawSprite(g, f1.getImage(), x, f1.getY());
      drawSprite(g, f2.getImage(), orp, f2.getY());
    } else {
      drawSprite(g, f2.getImage(), orp, f2.getY());
      drawSprite(g, f1.getImage(), x, f1.getY());
    }

    if (tnum == 16 || tnum == 15) {
      drawSprite(g, toasty, 608, 448);
    } else if (tnum == 2 || tnum == 1) {
      drawSprite(g, toasty, 608, 448);
    } else if (tnum < 15)
      drawSprite(g, toasty, 576, 416);

    int X = f1.getVitality(), W = 300-X;
    int Y = f2.getVitality(), Q = 300-Y;
    g.setColor(red);
    g.fillRect(10, 10, W, 15);
    g.fillRect(329+Y, 10, Q, 15);
    g.setColor(yellow);
    g.fillRect(W+10, 10, X, 15);
    g.fillRect(329, 10, Y, 15);
    g.setColor(white);
    g.drawRect(10, 10, 300, 15);
    markDirtyRegion(10, 10, 301, 16);
    g.drawRect(329, 10, 300, 15);
    markDirtyRegion(329, 10, 301, 16);

    if (delay > 0 && fighting && e >= 3)
      drawSprite(g, ready, dx, dy);
  }
}