/**
 * Meat Fighter
 * Copyright (C) 2003  Michael Birken
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Meat Fighter and JaminWare are trademarks of Michael Birken.
 * All Rights Reserved.
 * http://www.meatfighter.com
 * o__1@hotmail.com
 */
package meatfighter;

import gamingtools.*;
import java.awt.*;
import javax.swing.*;
import java.awt.event.*;

public class Introduction extends FrameBuilder {

  public static final int STATE_JAMINWARE = 0;
  public static final int STATE_JUMP = 1;
  public static final int STATE_PUNCH = 2;
  public static final int STATE_SLIDE = 3;
  public static final int STATE_FALL = 4;
  public static final int STATE_PAUSE1 = 5;
  public static final int STATE_TITLE = 6;
  public static final int STATE_SUBTITLE = 7;
  public static final int STATE_PAUSE2 = 8;
  public static final int STATE_ENTER1 = 9;
  public static final int STATE_ENTER2 = 10;
  public static final int STATE_NAMEUP = 11;

  private static final int[] jump = new int[12], Y = new int[24];

  static {
    for(int i = 1; i <= 6; i++)
      jump[6 - i] = jump[5 + i] = 180 + (int)(((double)(i*i*4))/5);
    for(int i = 0; i < 12; i++)
      Y[23-i] = Y[i] = 140 + i*2;
  }

  Image JaminWare;
  Image cheeseImg;
  Image frontImg1;
  Image frontImg2;
  Image arm1;
  Image arm2;
  Image title;
  Image warrior1;
  Image warrior2;
  Image enter;
  Image nameup;

  Audio musicIntro;
  Audio musicNameUp;

  int mode, x, y, w, h, ox, oy, e = 6, state, lastState = STATE_NAMEUP;
  int ji = 0, yi = 0;
  private static Introduction singleton;

  public static Introduction getInstance(int state) {
    if (singleton == null)
      singleton = new Introduction();
    singleton.setState(state);
    return singleton;
  }

  private void setState(int state) {
    switch(state) {
      case STATE_JAMINWARE:
        mode = 0;
        break;
      case STATE_NAMEUP:
        mode = 1970;
        break;
      default:
        mode = 0;
        break;
    }
  }

  private Introduction() {
  }

  public boolean isBackgroundSame() {

    boolean returnValue = true;

    switch(state) {
      case STATE_JUMP:
        returnValue = (lastState != STATE_JAMINWARE);
        break;
      case STATE_TITLE:
        returnValue = false;
        break;
      case STATE_ENTER2:
        returnValue = (lastState != STATE_ENTER1);
        break;
      case STATE_JAMINWARE:
        returnValue = (lastState != STATE_JAMINWARE);
    }

    lastState = state;

    return returnValue;
  }

  public void renderBackground(Graphics g) {

    switch(state) {
      case STATE_JAMINWARE:
      case STATE_ENTER2:
        g.setColor(Color.black);
        g.fillRect(0, 0, 640, 480);
        break;
      case STATE_JUMP:
      case STATE_PUNCH:
      case STATE_SLIDE:
      case STATE_FALL:
      case STATE_PAUSE1:
        g.drawImage(cheeseImg, 0, -40, null);
        break;
      case STATE_TITLE:
      case STATE_SUBTITLE:
      case STATE_PAUSE2:
      case STATE_ENTER1:
        g.drawImage(cheeseImg, 0, w, null);
        break;
      case STATE_NAMEUP:
        g.drawImage(nameup, 0, 0, null);
        break;
    }
  }

  public void renderBackground(
      Graphics g, int x, int y, int width, int height) {
    renderBackground(g);
  }

  public void renderForeground(Graphics g) {

    switch(state) {
      case STATE_JAMINWARE:
        drawSprite(g, JaminWare, x + Chaotic.nextInt(-4, 4),
          y + Chaotic.nextInt(-4, 4));
        break;
      case STATE_JUMP:
        drawSprite(g, arm1, 378, 286);
        drawSprite(g, frontImg1, Y[yi], jump[ji]);
        break;
      case STATE_PUNCH:
        drawSprite(g, arm2, 318, 301);
        drawSprite(g, frontImg2, yi, jump[ji]);
        break;
      case STATE_SLIDE:
        drawSprite(g, arm2, 318, 301);
        drawSprite(g, frontImg2, yi, jump[ji]);
        break;
      case STATE_FALL:
        drawSprite(g, arm2, 318, 301);
        drawSprite(g, frontImg2, yi, y);
        break;
      case STATE_PAUSE1:
        drawSprite(g, arm2, 318, 301);
        break;
      case STATE_TITLE:
        drawSprite(g, title, x, y);
        drawSprite(g, arm2, 318, h);
        break;
      case STATE_SUBTITLE:
        drawSprite(g, title, x, y);
        drawSprite(g, arm2, 318, h);
        drawSprite(g, warrior1, ox, 140);
        drawSprite(g, warrior2, oy, 140);
        break;
      case STATE_PAUSE2:
        drawSprite(g, title, x, y);
        drawSprite(g, arm2, 318, h);
        drawSprite(g, warrior1, ox, 140);
        drawSprite(g, warrior2, ox, 140);
      case STATE_ENTER1:
        drawSprite(g, title, x, y);
        drawSprite(g, arm2, 318, h);
        drawSprite(g, warrior1, ox, 140);
        drawSprite(g, warrior2, ox, 140);
        if (e >= 3)
          drawSprite(g, enter, oy, 420);
        break;
      case STATE_ENTER2:
        drawSprite(g, title, x, y);
        drawSprite(g, warrior1, ox, 140);
        drawSprite(g, warrior2, ox, 140);

        if (e >= 3)
          drawSprite(g, enter, oy, 420);
        break;
      case STATE_NAMEUP:
        if (e >= 3)
          drawSprite(g, enter, oy, 420);
        break;
    }
  }

  public void updateState() {
    int i;
    if (mode == 0) {
      Jukebox.playMusic(musicIntro);
      x = (640 - (w = JaminWare.getWidth(null))) >> 1;
      y = (480 - (h = JaminWare.getHeight(null))) >> 1;
      mode = 1;
      state = STATE_JAMINWARE;
    } else if (mode < 100) {
      state = STATE_JAMINWARE;
      mode++;
    } else if (mode < 154) {
      state = STATE_JUMP;
      mode++;
      if (++ji == 12)
        ji = 0;
      if (++yi == 24)
        yi = 0;
      y = 208;
    } else if (mode < 155) {
      state = STATE_PUNCH;
      Jukebox.PUNCH[4].play();
      mode++;
      yi = Y[yi];
    } else if (mode < 160) {
      state = STATE_SLIDE;
      mode++;
      yi -= 20;
      if (++ji == 12)
        ji = 0;
      if (++yi == 24)
        yi = 0;
    } else if (mode < 213) {
      state = STATE_FALL;
      mode++;
      y += 5;
    } else if (mode < 214) {
      state = STATE_PAUSE1;
      mode++;
      x = (640 - title.getWidth(null)) >> 1;
      y = -(title.getHeight(null)) >> 1;
      w = -40;
      h = 301;
    } else if (mode < 234) {
      state = STATE_TITLE;
      mode++;
      w += 2;
      h += 2;
      y += 5;
    } else if (mode < 235) {
      state = STATE_SUBTITLE;
      ox = -warrior1.getWidth(null);
      oy = 640;
      mode++;
    } else if (mode < 258) {
      state = STATE_SUBTITLE;
      ox += 20;
      oy -= 20;
      mode++;
    } else if (mode < 259) {
      state = STATE_PAUSE2;
      ox = (640 - warrior1.getWidth(null)) >> 1;
      oy = (640 - enter.getWidth(null)) >> 1;
      mode++;
    } else if (mode < 340) {
      state = STATE_ENTER1;
      if (e-- == 0)
        e = 6;
      mode++;
    } else if (mode < 341) {
      state = STATE_ENTER2;
      if (e-- == 0)
        e = 6;
    } else if (mode < 1970) {
    } else if (mode < 1971) {
      state = STATE_NAMEUP;
      oy = (640 - enter.getWidth(null)) >> 1;
      Jukebox.playMusic(musicNameUp);
      mode = 2169;
    } else if (mode < 2170) {
      state = STATE_NAMEUP;
      if (e-- == 0)
        e = 6;
    } else {
      state = STATE_JAMINWARE;
      x = y = w = h = ox = oy = ji = yi = mode = 0;
    }
  }

  public void introMusicStopped() {
    GraphicsSource.setRenderListener(new DemoStage());
  }

  public void nameUpMusicStopped() {
    x = y = w = h = ox = oy = ji = yi = mode = 0;
  }

  public void init() {

    if (enter == null) {
      enter = Gallery.TEXT_PRESS_ENTER;
      JaminWare = Gallery.JAMINWARE;
      cheeseImg = Gallery.BACKGROUND_CHEESE;
      nameup = Gallery.BACKGROUND_NAMEUP;
      frontImg1 = Gallery.JUMPING_FIGHTER[0];
      frontImg2 = Gallery.JUMPING_FIGHTER[1];
      arm1 = Gallery.ARM[0];
      arm2 = Gallery.ARM[1];
      title = Gallery.TEXT_MEAT_FIGHTER;
      warrior1 = Gallery.TEXT_WIENER_WARRIOR[0];
      warrior2 = Gallery.TEXT_WIENER_WARRIOR[1];

      musicNameUp = Jukebox.MUSIC_NAMEUP;
      musicNameUp.setAudioListener(new AudioListener() {
        public void audioStopped() {
          nameUpMusicStopped();
        }
      });
      musicIntro = Jukebox.MUSIC_INTRO;
      musicIntro.setAudioListener(new AudioListener() {
        public void audioStopped() {
          introMusicStopped();
        }
      });
    }
  }
}