/**
 * Meat Fighter
 * Copyright (C) 2003  Michael Birken
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Meat Fighter and JaminWare are trademarks of Michael Birken.
 * All Rights Reserved.
 * http://www.meatfighter.com
 * o__1@hotmail.com
 */
package meatfighter;

import gamingtools.*;

public final class Jukebox {

  public static final Audio CHOSEN;
  public static final Audio FIGHT;
  public static final Audio GIBBER;
  public static final Audio GIBBER3;
  public static final Audio OUCH;
  public static final Audio PUNCH1;
  public static final Audio PUNCH2;
  public static final Audio PUNCH3;
  public static final Audio PUNCH4;
  public static final Audio PUNCH5;
  public static final Audio SLIDE;
  public static final Audio SPLAT;
  public static final Audio TOASTY;
  public static final Audio[] PUNCH;

  public static final Audio MUSIC_BONUS_STAGE;
  public static final Audio MUSIC_BONUS_STAGE_BEGIN;
  public static final Audio MUSIC_CONTINUE;
  public static final Audio[] MUSIC_STAGE;
  public static final Audio MUSIC_NAMEUP;
  public static final Audio MUSIC_INTRO;
  public static final Audio MUSIC_SELECT_CHARACTER;
  public static final Audio MUSIC_VS;
  public static final Audio MUSIC_WINNING;

  static {
    CHOSEN = loadAudio("chosen.wav");
    FIGHT = loadAudio("fight.wav");
    GIBBER = loadAudio("gibber.wav");
    GIBBER3 = loadAudio("gibber3.wav");
    OUCH = loadAudio("ouch.wav");
    PUNCH1 = new AudioProxy(loadAudio("punch1.wav"));
    PUNCH2 = new AudioProxy(loadAudio("punch2.wav"));
    PUNCH3 = new AudioProxy(loadAudio("punch3.wav"));
    PUNCH4 = new AudioProxy(loadAudio("punch4.wav"));
    PUNCH5 = new AudioProxy(loadAudio("punch5.wav"));
    SLIDE = loadAudio("slide.wav");
    SPLAT = loadAudio("splat.wav");
    TOASTY = loadAudio("toasty.wav");

    PUNCH = new Audio[] { PUNCH1, PUNCH2, PUNCH3, PUNCH4, PUNCH5 };

    MUSIC_BONUS_STAGE = loadAudio("bonusstage.mid");
    MUSIC_BONUS_STAGE_BEGIN = loadAudio("begin.mid");
    MUSIC_CONTINUE = loadAudio("continue.mid");
    MUSIC_NAMEUP = loadAudio("nameup.mid");
    MUSIC_INTRO = loadAudio("intro.mid");
    MUSIC_SELECT_CHARACTER = loadAudio("menu.mid");
    MUSIC_VS = loadAudio("begin.mid");
    MUSIC_WINNING = loadAudio("winning.mid");

    MUSIC_STAGE = new Audio[6];
    for(int i = 0; i < 6; i++)
      MUSIC_STAGE[i] = loadAudio("stage" + (i+1) + ".mid");
  }

  private static Audio music;

  private Jukebox() {
  }

  private static void setMusic(Audio music) {
    if (Jukebox.music != null)
      Jukebox.music.stop();
    Jukebox.music = music;
  }

  public static synchronized void playMusic(Audio music) {
    setMusic(music);
    music.play();
  }

  public static synchronized void loopMusic(Audio music) {
    setMusic(music);
    music.loop();
  }

  public static synchronized void stopMusic() {
    if (Jukebox.music != null)
      Jukebox.music.stop();
    Jukebox.music = null;
  }

  private static Audio loadAudio(String fileName) {
    Audio aud = AudioSource.getAudio(fileName);
    ProgressBar.fileCount++;
    return aud;
  }

  public static void disposeAll() {
    CHOSEN.dispose();
    FIGHT.dispose();
    GIBBER.dispose();
    GIBBER3.dispose();
    OUCH.dispose();
    PUNCH1.dispose();
    PUNCH2.dispose();
    PUNCH3.dispose();
    PUNCH4.dispose();
    PUNCH5.dispose();
    SLIDE.dispose();
    SPLAT.dispose();
    TOASTY.dispose();

    MUSIC_BONUS_STAGE.dispose();
    MUSIC_BONUS_STAGE_BEGIN.dispose();
    MUSIC_CONTINUE.dispose();
    MUSIC_NAMEUP.dispose();
    MUSIC_INTRO.dispose();
    MUSIC_SELECT_CHARACTER.dispose();
    MUSIC_VS.dispose();
    MUSIC_WINNING.dispose();

    for(int i = MUSIC_STAGE.length - 1; i >= 0; i--)
      MUSIC_STAGE[i].dispose();
  }
}